@@ -39,8 +39,7 @@ setMethodS3("fromDataFile", "ChipEffectFile", function(static, df=NULL, filename
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'df':
   if (!is.null(df)) {
-    if (!inherits(df, "AffymetrixCelFile"))
-      throw("Argument 'df' is not an AffymetrixCelFile: ", class(df)[1]);
+    df <- Arguments$getInstanceOf(df, "AffymetrixCelFile");
   }
 
   # Argument 'cdf':
@@ -48,8 +47,7 @@ setMethodS3("fromDataFile", "ChipEffectFile", function(static, df=NULL, filename
     if (is.null(df))
       throw("Either argument 'df' or 'cdf' must specified.");
   } else {
-    if (!inherits(cdf, "AffymetrixCdfFile"))
-      throw("Argument 'cdf' is not an AffymetrixCdfFile: ", class(cdf)[1]);
+    cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile");
   }
 
   # Argument 'filename' & 'path':
