@@ -108,7 +108,6 @@ setMethodS3("exportTotalAndFracB", "DChipDcpSet", function(this, ..., overwrite=
     tmpPathname <- sprintf("%s.tmp", pathname);
     tmpPathname <- Arguments$getWritablePathname(tmpPathname, mustNotExist=TRUE);
     asb <- AromaUnitSignalBinaryFile$allocate(tmpPathname, nbrOfRows=nbrOfUnits(cdf), platform=platform, chipType=chipType);
-    asb[,1] <- as.double(NA);
     verbose && print(verbose, asb);
     verbose && exit(verbose);
   
@@ -158,6 +157,9 @@ setMethodS3("exportTotalAndFracB", "DChipDcpSet", function(this, ..., overwrite=
 
 ############################################################################
 # HISTORY:
+# 2010-01-06
+# o CLEAN UP: No need for assign NAs when allocating new files; this is now
+#   always the default way (in aroma.core v1.4.1). 
 # 2009-02-13
 # o Added exportTotalFracB().
 # o Added getCdfBin().
