@@ -93,6 +93,9 @@ setMethodS3("getTags", "FirmaModel", function(this, collapse=NULL, ...) {
   # Get class specific tags
   tags <- this$.tags;
 
+  # In case this$.tags is not already split
+  tags <- strsplit(tags, split=",", fixed=TRUE)[[1]];
+
   # Expand asterisk tags
   if (any(tags == "*")) {
     tags[tags == "*"] <- getAsteriskTags(this, collapse=",");
